<?php
 
/*
* File: SimpleImage.php
* Author: Simon Jarvis
* Copyright: 2006 Simon Jarvis
* Date: 08/11/06
* Link: http://www.white-hat-web-design.co.uk/articles/php-image-resizing.php
*
* This program is free software; you can redistribute it and/or
* modify it under the terms of the GNU General Public License
* as published by the Free Software Foundation; either version 2
* of the License, or (at your option) any later version.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* GNU General Public License for more details:
* http://www.gnu.org/licenses/gpl.html
*
*/
 
class SimpleImage {
 
   var $image;
   var $image_type;
 
   function load($filename) {
 
      // Kép szélességének, magasságának lekérdezése.
      $image_info = getimagesize($filename);
      $this->image_type = $image_info[2];
      if( $this->image_type == IMAGETYPE_JPEG ) {
         // jpg megnyitása.
         $this->image = imagecreatefromjpeg($filename);
      } elseif( $this->image_type == IMAGETYPE_GIF ) {
         // gif megnyitása.
         $this->image = imagecreatefromgif($filename);
      } elseif( $this->image_type == IMAGETYPE_PNG ) {
         // png megnyitása.
         $this->image = imagecreatefrompng($filename);
      }
   }
   
   function save($filename, $image_type=IMAGETYPE_JPEG, $compression=75, $permissions=null) {
 
      if( $image_type == IMAGETYPE_JPEG ) {
         // jpg kép készítése. Az eredmény a $filename által mutatott helyre kerül.
         imagejpeg($this->image,$filename,$compression);
      } elseif( $image_type == IMAGETYPE_GIF ) {
 
         imagegif($this->image,$filename);
      } elseif( $image_type == IMAGETYPE_PNG ) {
 
         imagepng($this->image,$filename);
      }
      if( $permissions != null) {
 
         chmod($filename,$permissions);
      }
   }
   
   function output($image_type=IMAGETYPE_JPEG) {
 
      if( $image_type == IMAGETYPE_JPEG ) {
		 header("Content-type: image/jpeg");
         imagejpeg($this->image);
      } elseif( $image_type == IMAGETYPE_GIF ) {
		 header("Content-type: image/gif");
         imagegif($this->image);
      } elseif( $image_type == IMAGETYPE_PNG ) {
		 header("Content-type: image/png");
         imagepng($this->image);
      }
   }
   
   function getWidth() {
      // Kép szélességének lekérése.
      return imagesx($this->image);
   }
   
   function getHeight() {
      // Kép magasságának lekérése.
      return imagesy($this->image);
   }
   
   function resizeToHeight($height) {
      $ratio = $height / $this->getHeight();
      $width = $this->getWidth() * $ratio;
      $this->resize($width,$height);
   }
 
   function resizeToWidth($width) {
      $ratio = $width / $this->getWidth();
      $height = $this->getheight() * $ratio;
      $this->resize($width,$height);
   }
 
   function scale($scale) {
      $width = $this->getWidth() * $scale/100;
      $height = $this->getheight() * $scale/100;
      $this->resize($width,$height);
   }
 
   function resize($width,$height) {
      // Egy üres fekete kép készítése a megadott mérettel.
      $new_image = imagecreatetruecolor($width, $height);
      // Kép átméretezése. Az eredeti kép egy részének átmásolása az új képre a megadott méretekkel.
      imagecopyresampled($new_image, $this->image, 0, 0, 0, 0, $width, $height, $this->getWidth(), $this->getHeight());
      $this->image = $new_image;
   }
   
   function writeString($string, $red = 0, $green = 0, $blue = 0) {
		$textcolor = imagecolorallocate($this->image, $red, $green, $blue);
		imagestring($this->image, 5, 5, 5, $string, $textcolor);
		
   }
   
   function getStringWidth($string) {
     return imagefontwidth(5) * strlen($string);
   }
   
   function getStringHeight() {
     return imagefontheight(5);
   }
   
   function createBlankImage($width, $height) {
      $img = imagecreatetruecolor($width, $height);
	  $bg = imagecolorallocate($img, 255, 255, 255);
	  imagefill($img, 0, 0, $bg);
	  $this->image = $img;
   }
 
}
